window.Gleam.initSearch([{"doc":"gloom","title":"gloom","content":"# Gloom\n\nGloom is a hardcore language for building extreme systems, designed from the ground up for getting real work done. Unlike other languages that supposedly provide safety and reliability (aka bureaucratic paperwork), Gloom embraces the idea that there&#39;s an element of danger in most things worth doing. Hence all computations in Gloom have side effects. So little as printing an object changes its state. In blending operations and consequences, the Gloom language forces developers to become acutely mindful of their actions and the immediate repercussions those actions have on their systems.\n\nGloom&#39;s philosophy hinges on the belief that programming, much like life itself, is messy, unpredictable, and filled with risks. Rather than hiding from these realities, Gloom programmers are encouraged to master them. This brutal approach may not be for the faint of heart, but for those who crave raw, unfiltered interaction with their code, Gloom offers an unparalleled experience.\n\n# Status\n\nThis is in early stages. Currently this repository is more of a playground to work out the language&#39;s semantics, so nothing here really works at the moment.\n\n# Grammar (tentative)\n\n```ebnf\n    program = { statement }\n    statement = message_send &quot;.&quot;\n    message_send = receiver { argument } \n    receiver = &quot;(&quot; message_send &quot;)&quot; | value\n    argument = named_parameter | binary_parameter | unary_parameter\n    unary_parameter = &quot;:&quot; name\n    named_parameter = &quot;:&quot; parameter_name value\n    binary_parameter = operator value\n    operator = &quot;+&quot; | &quot;-&quot; | &quot;,&quot; | &quot;*&quot; | &quot;/&quot; | &quot;%&quot;\n    value = literal | name | &quot;(&quot; message_send &quot;)&quot;\n    literal = number | string | boolean | array\n    array = &quot;(&quot; { literal }&quot;)&quot;\n    name = letter { letter | digit }\n```\n\n# Disclaimer\n\nThis is all intended to be silly -- Gloom is an artlang and learning project. Please use whatever guardrails make sense for your use-case. Guardrails like types and memory safety are nice because people make mistakes. Please be nice to each other ","url":"index.html"},{"doc":"template","title":"template_replace_all","content":"pub fn template_replace_all(template: String, parameter_mappings: Map(\n    String,\n    String,\n  )) -&gt; String\n\nSynonyms:\ntemplate.template_replace_all\ntemplate template_replace_all","url":"template.html#template_replace_all"},{"doc":"template","title":"template","content":"","url":"template.html"},{"doc":"affinity","title":"GloomAffinity","content":"pub type GloomAffinity {\n  Nothing\n  Everything\n  Something\n}\n\nNothing\n\n\nEverything\n\n\nSomething\n\n\nSynonyms:\naffinity.GloomAffinity\naffinity GloomAffinity","url":"affinity.html#GloomAffinity"},{"doc":"affinity","title":"affinity_max","content":"pub fn affinity_max(left: GloomAffinity, right: GloomAffinity) -&gt; GloomAffinity\n\nSynonyms:\naffinity.affinity_max\naffinity affinity_max","url":"affinity.html#affinity_max"},{"doc":"affinity","title":"affinity","content":"","url":"affinity.html"},{"doc":"dtype","title":"GloomType","content":"pub type GloomType {\n  Number\n  String\n  Table\n}\n\nNumber\n\n\nString\n\n\nTable\n\n\nSynonyms:\ndtype.GloomType\ndtype GloomType","url":"dtype.html#GloomType"},{"doc":"dtype","title":"dtype","content":"","url":"dtype.html"},{"doc":"gleam_value","title":"GleamValue","content":"pub type GleamValue {\n  IntValue(value: Int)\n  FloatValue(value: Float)\n  StringValue(value: String)\n  MapValue(value: map.Map(GleamValue, GleamValue))\n  ObjectValue(value: GloomObject)\n}\n\nIntValue(value: Int)\n\n\nFloatValue(value: Float)\n\n\nStringValue(value: String)\n\n\nMapValue(value: map.Map(GleamValue, GleamValue))\n\n\nObjectValue(value: GloomObject)\n\n\nSynonyms:\ngleam_value.GleamValue\ngleam_value GleamValue","url":"gleam_value.html#GleamValue"},{"doc":"gleam_value","title":"GloomObject","content":"pub type GloomObject {\n  GloomObject(\n    name: String,\n    datatype: GloomType,\n    affinity: GloomAffinity,\n    properties: GleamValue,\n  )\n}\n\nGloomObject(\n  name: String,\n  datatype: GloomType,\n  affinity: GloomAffinity,\n  properties: GleamValue,\n)\n\n\nSynonyms:\ngleam_value.GloomObject\ngleam_value GloomObject","url":"gleam_value.html#GloomObject"},{"doc":"gleam_value","title":"empty_map","content":"pub fn empty_map() -&gt; GleamValue\n\nSynonyms:\ngleam_value.empty_map\ngleam_value empty_map","url":"gleam_value.html#empty_map"},{"doc":"gleam_value","title":"empty_number","content":"pub fn empty_number() -&gt; GleamValue\n\nSynonyms:\ngleam_value.empty_number\ngleam_value empty_number","url":"gleam_value.html#empty_number"},{"doc":"gleam_value","title":"empty_string","content":"pub fn empty_string() -&gt; GleamValue\n\nSynonyms:\ngleam_value.empty_string\ngleam_value empty_string","url":"gleam_value.html#empty_string"},{"doc":"gleam_value","title":"empty_value","content":"pub fn empty_value(datatype: GloomType) -&gt; GleamValue\n\nSynonyms:\ngleam_value.empty_value\ngleam_value empty_value","url":"gleam_value.html#empty_value"},{"doc":"gleam_value","title":"ensure_map_value","content":"pub fn ensure_map_value(value: GleamValue) -&gt; GleamValue\n\nSynonyms:\ngleam_value.ensure_map_value\ngleam_value ensure_map_value","url":"gleam_value.html#ensure_map_value"},{"doc":"gleam_value","title":"ensure_object_value","content":"pub fn ensure_object_value(value: GleamValue) -&gt; GleamValue\n\nSynonyms:\ngleam_value.ensure_object_value\ngleam_value ensure_object_value","url":"gleam_value.html#ensure_object_value"},{"doc":"gleam_value","title":"everything","content":"pub fn everything(datatype: GloomType) -&gt; GloomObject\n\nSynonyms:\ngleam_value.everything\ngleam_value everything","url":"gleam_value.html#everything"},{"doc":"gleam_value","title":"everything_value","content":"pub fn everything_value(value: GleamValue) -&gt; GloomObject\n\nSynonyms:\ngleam_value.everything_value\ngleam_value everything_value","url":"gleam_value.html#everything_value"},{"doc":"gleam_value","title":"from_float","content":"pub fn from_float(float: Float) -&gt; GleamValue\n\nSynonyms:\ngleam_value.from_float\ngleam_value from_float","url":"gleam_value.html#from_float"},{"doc":"gleam_value","title":"from_int","content":"pub fn from_int(int: Int) -&gt; GleamValue\n\nSynonyms:\ngleam_value.from_int\ngleam_value from_int","url":"gleam_value.html#from_int"},{"doc":"gleam_value","title":"from_list","content":"pub fn from_list(list: List(#(GleamValue, GleamValue))) -&gt; GleamValue\n\nSynonyms:\ngleam_value.from_list\ngleam_value from_list","url":"gleam_value.html#from_list"},{"doc":"gleam_value","title":"from_string","content":"pub fn from_string(string: String) -&gt; GleamValue\n\nSynonyms:\ngleam_value.from_string\ngleam_value from_string","url":"gleam_value.html#from_string"},{"doc":"gleam_value","title":"get","content":"pub fn get(maybe_map: GleamValue, key: GleamValue) -&gt; GleamValue\n\nSynonyms:\ngleam_value.get\ngleam_value get","url":"gleam_value.html#get"},{"doc":"gleam_value","title":"get_property","content":"pub fn get_property(object: GloomObject, key: GleamValue) -&gt; GloomObject\n\nSynonyms:\ngleam_value.get_property\ngleam_value get_property","url":"gleam_value.html#get_property"},{"doc":"gleam_value","title":"gloom_type","content":"pub fn gloom_type(gleam_value: GleamValue) -&gt; GloomType\n\nSynonyms:\ngleam_value.gloom_type\ngleam_value gloom_type","url":"gleam_value.html#gloom_type"},{"doc":"gleam_value","title":"insert","content":"pub fn insert(maybe_map: GleamValue, key: GleamValue, value: GleamValue) -&gt; GleamValue\n\nSynonyms:\ngleam_value.insert\ngleam_value insert","url":"gleam_value.html#insert"},{"doc":"gleam_value","title":"insert_value","content":"pub fn insert_value(hopefully_map: GleamValue, value: GleamValue) -&gt; GleamValue\n\nSynonyms:\ngleam_value.insert_value\ngleam_value insert_value","url":"gleam_value.html#insert_value"},{"doc":"gleam_value","title":"length","content":"pub fn length(value: GleamValue) -&gt; Int\n\nSynonyms:\ngleam_value.length\ngleam_value length","url":"gleam_value.html#length"},{"doc":"gleam_value","title":"nothing","content":"pub fn nothing(datatype: GloomType) -&gt; GloomObject\n\nSynonyms:\ngleam_value.nothing\ngleam_value nothing","url":"gleam_value.html#nothing"},{"doc":"gleam_value","title":"nothing_value","content":"pub fn nothing_value(value: GleamValue) -&gt; GloomObject\n\nSynonyms:\ngleam_value.nothing_value\ngleam_value nothing_value","url":"gleam_value.html#nothing_value"},{"doc":"gleam_value","title":"set_property","content":"pub fn set_property(object: GloomObject, key: GleamValue, value: GleamValue) -&gt; GloomObject\n\nSynonyms:\ngleam_value.set_property\ngleam_value set_property","url":"gleam_value.html#set_property"},{"doc":"gleam_value","title":"something","content":"pub fn something(datatype: GloomType) -&gt; GloomObject\n\nSynonyms:\ngleam_value.something\ngleam_value something","url":"gleam_value.html#something"},{"doc":"gleam_value","title":"something_value","content":"pub fn something_value(value: GleamValue) -&gt; GloomObject\n\nSynonyms:\ngleam_value.something_value\ngleam_value something_value","url":"gleam_value.html#something_value"},{"doc":"gleam_value","title":"gleam_value","content":"","url":"gleam_value.html"},{"doc":"repr","title":"object_repr","content":"pub fn object_repr(object: GloomObject) -&gt; String\n\nSynonyms:\nrepr.object_repr\nrepr object_repr","url":"repr.html#object_repr"},{"doc":"repr","title":"print","content":"pub fn print(object: GloomObject) -&gt; Nil\n\nSynonyms:\nrepr.print\nrepr print","url":"repr.html#print"},{"doc":"repr","title":"repr","content":"","url":"repr.html"},{"doc":"parse","title":"parse","content":"","url":"parse.html"},{"doc":"gloom","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\ngloom.main\ngloom main","url":"gloom.html#main"},{"doc":"gloom","title":"gloom","content":"","url":"gloom.html"},{"doc":"environment","title":"environment","content":"","url":"environment.html"},{"doc":"message","title":"GloomMessage","content":"pub type GloomMessage {\n  UnaryMessage(selector: String)\n  BinaryMessage(selector: String, argument: GloomObject)\n  NamedMessage(arguments: GloomObject)\n  Noop\n}\n\nUnaryMessage(selector: String)\n\n\nBinaryMessage(selector: String, argument: GloomObject)\n\n\nNamedMessage(arguments: GloomObject)\n\n\nNoop\n\n\nSynonyms:\nmessage.GloomMessage\nmessage GloomMessage","url":"message.html#GloomMessage"},{"doc":"message","title":"MessageSend","content":"pub type MessageSend {\n  MessageSend(recipient: GloomObject, message: GloomMessage)\n}\n\nMessageSend(recipient: GloomObject, message: GloomMessage)\n\n\nSynonyms:\nmessage.MessageSend\nmessage MessageSend","url":"message.html#MessageSend"},{"doc":"message","title":"message","content":"","url":"message.html"}]);